@@ -1,26 +1,13 @@
-/*****************************************************************************
- * This file is part of Kiten, a KDE Japanese Reference Tool...              *
- * Copyright (C) 2001 Jason Katz-Brown <jason@katzbrown.com>                 *
- * Copyright (C) 2005 Paul Temple <paul.temple@gmx.net>                      *
- * Copyright (C) 2006 Joseph Kerian <jkerian@gmail.com>                      *
- * Copyright (C) 2006 Eric Kjeldergaard <kjelderg@gmail.com>                 *
- * Copyright (C) 2011 Daniel E. Moctezuma <democtezuma@gmail.com>            *
- *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
- * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
- * (at your option) any later version.                                       *
- *                                                                           *
- * This program is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
- * GNU General Public License for more details.                              *
- *                                                                           *
- * You should have received a copy of the GNU General Public License         *
- * along with this program; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 *
- * USA                                                                       *
- *****************************************************************************/
+/*
+    This file is part of Kiten, a KDE Japanese Reference Tool...
+    SPDX-FileCopyrightText: 2001 Jason Katz-Brown <jason@katzbrown.com>
+    SPDX-FileCopyrightText: 2005 Paul Temple <paul.temple@gmx.net>
+    SPDX-FileCopyrightText: 2006 Joseph Kerian <jkerian@gmail.com>
+    SPDX-FileCopyrightText: 2006 Eric Kjeldergaard <kjelderg@gmail.com>
+    SPDX-FileCopyrightText: 2011 Daniel E. Moctezuma <democtezuma@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef KITEN_H
 #define KITEN_H
@@ -33,7 +20,6 @@
 #include "historyptrlist.h"
 
 class QAction;
-class KGlobalAccel;
 class KListAction;
 class KProcess;
 class QStatusBar;
@@ -61,7 +47,7 @@ class Kiten : public KXmlGuiWindow
     KitenConfigSkeleton *getConfig();
 
   // The following will be available via dbus.
-  public slots:
+  public Q_SLOTS:
     void searchTextAndRaise( const QString &str );
     void addExportListEntry( int index );
 
@@ -70,7 +56,7 @@ class Kiten : public KXmlGuiWindow
     void setupExportListDock();
     bool queryClose() override; //overridden from KXmlGuiWindow (called@shutdown) override
 
-  private slots:
+  private Q_SLOTS:
     void finishInit();
     void focusResultsView();
 
@@ -111,7 +97,7 @@ class Kiten : public KXmlGuiWindow
   //	void createEEdit();
   //	void kanjiDictChange();
   //	void slotLearnConfigure();
-  //signals:
+  //Q_SIGNALS:
   //	void saveLists();
   //	void add( Entry* );
 
@@ -145,7 +131,6 @@ class Kiten : public KXmlGuiWindow
     QWidget                 *_exportListDockContents = nullptr;
     EntryListView           *_exportList = nullptr;
 
-    KGlobalAccel            *_accel = nullptr;
     ConfigureDialog         *_optionDialog = nullptr;
     KitenConfigSkeleton     *_config = nullptr;
 
